package java.lang;

import java.io.InputStream;
import java.net.URL;
import java.util.Hashtable;

public abstract class ClassLoader {
   private boolean initialized = false;
   private Hashtable classes = new Hashtable();

   protected ClassLoader() {
      SecurityManager var1 = System.getSecurityManager();
      if (var1 != null) {
         var1.checkCreateClassLoader();
      }

      this.init();
      this.initialized = true;
   }

   public Class loadClass(String var1) throws ClassNotFoundException {
      return this.loadClass(var1, true);
   }

   protected abstract Class loadClass(String var1, boolean var2) throws ClassNotFoundException;

   /** @deprecated */
   protected final Class defineClass(byte[] var1, int var2, int var3) {
      return this.defineClass((String)null, var1, var2, var3);
   }

   protected final Class defineClass(String var1, byte[] var2, int var3, int var4) {
      this.check();
      Class var5 = this.defineClass0(var1, var2, var3, var4);
      if (var5 != null) {
         this.classes.put(var5.getName(), var5);
      }

      return var5;
   }

   protected final void resolveClass(Class var1) {
      this.check();
      this.resolveClass0(var1);
   }

   protected final Class findSystemClass(String var1) throws ClassNotFoundException {
      this.check();
      return this.findSystemClass0(var1);
   }

   protected final void setSigners(Class var1, Object[] var2) {
      this.check();
      var1.setSigners(var2);
   }

   private native void init();

   private native Class defineClass0(String var1, byte[] var2, int var3, int var4);

   private native void resolveClass0(Class var1);

   private native Class findSystemClass0(String var1) throws ClassNotFoundException;

   private void check() {
      if (!this.initialized) {
         throw new SecurityException("ClassLoader object not initialized.");
      }
   }

   protected final Class findLoadedClass(String var1) {
      return (Class)this.classes.get(var1);
   }

   final Class loadClassInternal(String var1, boolean var2) throws ClassNotFoundException {
      var1 = var1.replace('/', '.');
      Class var3 = (Class)this.classes.get(var1);
      if (var3 == null) {
         var3 = this.loadClass(var1, false);
         if (var3 == null) {
            throw new ClassNotFoundException(var1);
         }

         String var4 = var3.getName();
         if (!var4.equals(var1)) {
            throw new ClassNotFoundException(var1);
         }

         this.classes.put(var4, var3);
      }

      if (var2) {
         this.resolveClass(var3);
      }

      return var3;
   }

   public static final InputStream getSystemResourceAsStream(String var0) {
      return getSystemResourceAsStream0(var0);
   }

   public static final URL getSystemResource(String var0) {
      String var1 = getSystemResourceAsName0(var0);

      URL var2;
      try {
         var2 = new URL(var1);
      } catch (Exception var3) {
         var2 = null;
      }

      return var2;
   }

   public InputStream getResourceAsStream(String var1) {
      return null;
   }

   public URL getResource(String var1) {
      return null;
   }

   private static native InputStream getSystemResourceAsStream0(String var0);

   private static native String getSystemResourceAsName0(String var0);
}
