package java.lang.reflect;

public final class Constructor implements Member {
   private Class clazz;
   private int slot;
   private Class[] parameterTypes;
   private Class[] exceptionTypes;

   private Constructor() {
   }

   public Class getDeclaringClass() {
      return this.clazz;
   }

   public String getName() {
      return this.getDeclaringClass().getName();
   }

   public native int getModifiers();

   public Class[] getParameterTypes() {
      return Method.copy(this.parameterTypes);
   }

   public Class[] getExceptionTypes() {
      return Method.copy(this.exceptionTypes);
   }

   public boolean equals(Object var1) {
      if (var1 != null && var1 instanceof Constructor) {
         Constructor var2 = (Constructor)var1;
         if (this.getDeclaringClass() == var2.getDeclaringClass()) {
            Class[] var3 = this.parameterTypes;
            Class[] var4 = var2.parameterTypes;
            if (var3.length == var4.length) {
               for(int var5 = 0; var5 < var3.length; ++var5) {
                  if (var3[var5] != var4[var5]) {
                     return false;
                  }
               }

               return true;
            }
         }
      }

      return false;
   }

   public int hashCode() {
      return this.getDeclaringClass().getName().hashCode();
   }

   public String toString() {
      try {
         StringBuffer var1 = new StringBuffer();
         int var2 = this.getModifiers();
         if (var2 != 0) {
            var1.append(Modifier.toString(var2) + " ");
         }

         var1.append(Field.getTypeName(this.getDeclaringClass()));
         var1.append("(");
         Class[] var3 = this.parameterTypes;

         for(int var4 = 0; var4 < var3.length; ++var4) {
            var1.append(Field.getTypeName(var3[var4]));
            if (var4 < var3.length - 1) {
               var1.append(",");
            }
         }

         var1.append(")");
         Class[] var5 = this.exceptionTypes;
         if (var5.length > 0) {
            var1.append(" throws ");

            for(int var6 = 0; var6 < var5.length; ++var6) {
               var1.append(var5[var6].getName());
               if (var6 < var5.length - 1) {
                  var1.append(",");
               }
            }
         }

         return var1.toString();
      } catch (Exception var7) {
         return "<" + var7 + ">";
      }
   }

   public native Object newInstance(Object[] var1) throws InstantiationException, IllegalAccessException, IllegalArgumentException, InvocationTargetException;
}
